@@ -55,6 +55,7 @@ The project's page is at http://winni.vdr-developer.org/epgsearch
 
 const char AllowedChars[] = trNOOP("$ abcdefghijklmnopqrstuvwxyz0123456789-.,#~\\^$[]|()*+?{}/:%@&_");
 extern bool isUTF8;
+extern bool VDR_readyafterStartup;
 
 int CompareEventTime(const void *p1, const void *p2)
 {
@@ -358,13 +359,59 @@ std::string strreplace(
     const std::string& replaceWithWhat)
 {
     while (1) {
-        const int pos = result.find(replaceWhat);
-        if (pos == -1) break;
+        const std::size_t pos = result.find(replaceWhat);
+        if (pos == std::string::npos) break;
         result.replace(pos, replaceWhat.size(), replaceWithWhat);
     }
     return result;
 }
 
+char* encodeSpecialCharacters(const char* s, bool nestedColon)
+{
+    char* result = strdup(s);
+    while (strchr(result, '|')) result = strreplace(result, "|", PIPE);
+    if (nestedColon) {
+        while (strchr(result, ':')) result = strreplace(result, ":", COLON);
+    } else {
+        result = strreplace(result, ':', '|');
+    }
+    return result;
+}
+
+std::string encodeSpecialCharacters(std::string s, bool nestedColon)
+{
+    s = ReplaceAll(s, "|", PIPE);
+    if (nestedColon) {
+        s = ReplaceAll(s, ":", COLON);
+    } else {
+        s = ReplaceAll(s, ":", "|");
+    }
+    return s;
+
+}
+
+char* decodeSpecialCharacters(const char* s, bool nestedColon)
+{
+    char* result = strdup(s);
+    if (nestedColon) {
+        while (strstr(result, COLON)) result = strreplace(result, COLON, ":");
+    } else {
+        result = strreplace(result, '|', ':');
+    }
+    while (strstr(result, PIPE)) result = strreplace(result, PIPE, "|");
+    return result;
+}
+
+std::string decodeSpecialCharacters(std::string s, bool nestedColon)
+{
+    if (nestedColon) {
+        s = ReplaceAll(s, COLON, ":");
+    } else {
+        s = ReplaceAll(s, "|", ":");
+    }
+    s = ReplaceAll(s, PIPE, "|");
+    return s;
+}
 
 void sleepMSec(long ms)
 {
@@ -376,6 +423,23 @@ void sleepSec(long s)
     sleepMSec(s * 1000);
 }
 
+void WaitVDRReady()
+{
+    // if vdr has switched to the first program
+    // we can be sure that SVDRP is setup
+    int count = 0;
+    while (count < 90  && !VDR_readyafterStartup && !cDevice::PrimaryDevice()->HasProgramme()) {
+        cCondWait::SleepMs(2000);
+        count++;
+    }
+    if (count == 90) {
+        LogFile.eSysLog("Please check svdrp - Searchtimers and Switchtimers might not work");
+    } else {
+        LogFile.Log(2, "VDR Ready after %d seconds", count*2);
+    }
+    VDR_readyafterStartup = true; // VDR is ready or we waited 3 minutes
+}
+
 bool SendViaSVDRP(cString SVDRPcmd)
 {
     bool bSuccess = true;
@@ -844,6 +908,11 @@ int msprintf(char **strp, const char *fmt, ...)
     va_start(ap, fmt);
     int res = vasprintf(strp, fmt, ap);
     va_end(ap);
+    if (res < 0) {
+        // to avoid free() on an undefined pointer, since the manual states:
+        // "...will return -1, and the contents of strp are undefined"
+        *strp = NULL;
+    }
     return res;
 }
 
@@ -868,24 +937,20 @@ std::string GetCodeset()
 }
 
 /*  Read a line from a socket  */
-ssize_t Readline(int sockd, char *vptr, size_t maxlen)
+ssize_t Readline(int sockd, char *vptr, size_t size)
 {
     size_t n, rc;
-    char    c, *buffer;
+    char c, *buffer;
 
-    buffer = vptr;
-
-    for (n = 1; n < maxlen; n++) {
+    if (!(buffer = vptr) || size-- < 1) return 0;
+    for (n = 0; n < size; n++) {
 
         if ((rc = read(sockd, &c, 1)) == 1) {
             if (c == '\n')
                 break;
             *buffer++ = c;
         } else if (rc == 0) {
-            if (n == 1)
-                return 0;
-            else
-                break;
+            break;
         } else {
             if (errno == EINTR)
                 continue;
